@@ -59,8 +59,16 @@ class Pelias(Geocoder):
                 This format is now deprecated in favor of a list/tuple
                 of a pair of geopy Points and will be removed in geopy 2.0.
 
+            .. deprecated:: 1.19.0
+                This argument will be removed in geopy 2.0.
+                Use `geocode`'s `boundary_rect` instead.
+
         :param str country_bias: Bias results to this country (ISO alpha-3).
 
+            .. deprecated:: 1.19.0
+                This argument will be removed in geopy 2.0.
+                Use `geocode`'s `country_bias` instead.
+
         :param int timeout:
             See :attr:`geopy.geocoders.options.default_timeout`.
 
@@ -86,7 +94,25 @@ class Pelias(Geocoder):
             user_agent=user_agent,
             ssl_context=ssl_context,
         )
+        if country_bias is not None:
+            warnings.warn(
+                '`country_bias` argument of the %(cls)s.__init__ '
+                'is deprecated and will be removed in geopy 2.0. Use '
+                '%(cls)s.geocode(country_bias=%(value)r) instead.'
+                % dict(cls=type(self).__name__, value=country_bias),
+                DeprecationWarning,
+                stacklevel=2
+            )
         self.country_bias = country_bias
+        if boundary_rect is not None:
+            warnings.warn(
+                '`boundary_rect` argument of the %(cls)s.__init__ '
+                'is deprecated and will be removed in geopy 2.0. Use '
+                '%(cls)s.geocode(boundary_rect=%(value)r) instead.'
+                % dict(cls=type(self).__name__, value=boundary_rect),
+                DeprecationWarning,
+                stacklevel=2
+            )
         self.boundary_rect = boundary_rect
         self.api_key = api_key
         self.domain = domain.strip('/')
@@ -103,6 +129,8 @@ class Pelias(Geocoder):
             query,
             exactly_one=True,
             timeout=DEFAULT_SENTINEL,
+            boundary_rect=None,
+            country_bias=None,
     ):
         """
         Return a location point by address.
@@ -118,6 +146,17 @@ class Pelias(Geocoder):
             exception. Set this only if you wish to override, on this call
             only, the value set during the geocoder's initialization.
 
+        :type boundary_rect: list or tuple of 2 items of :class:`geopy.point.Point`
+            or ``(latitude, longitude)`` or ``"%(latitude)s, %(longitude)s"``.
+        :param boundary_rect: Coordinates to restrict search within.
+            Example: ``[Point(22, 180), Point(-22, -180)]``.
+
+            .. versionadded:: 1.19.0
+
+        :param str country_bias: Bias results to this country (ISO alpha-3).
+
+            .. versionadded:: 1.19.0
+
         :rtype: ``None``, :class:`geopy.location.Location` or a list of them, if
             ``exactly_one=False``.
         """
@@ -128,13 +167,14 @@ class Pelias(Geocoder):
                 'api_key': self.api_key
             })
 
-        if self.boundary_rect:
+        if boundary_rect is None:
             boundary_rect = self.boundary_rect
+        if boundary_rect:
             if len(boundary_rect) == 4:
                 warnings.warn(
                     '%s `boundary_rect` format of '
                     '`[longitude, latitude, longitude, latitude]` is now '
-                    'deprecated and will be not supported in geopy 2.0. '
+                    'deprecated and will not be supported in geopy 2.0. '
                     'Use `[Point(latitude, longitude), Point(latitude, longitude)]` '
                     'instead.' % type(self).__name__,
                     DeprecationWarning,
@@ -149,8 +189,10 @@ class Pelias(Geocoder):
             params['boundary.rect.max_lon'] = lon2
             params['boundary.rect.max_lat'] = lat2
 
-        if self.country_bias:
-            params['boundary.country'] = self.country_bias
+        if country_bias is None:
+            country_bias = self.country_bias
+        if country_bias:
+            params['boundary.country'] = country_bias
 
         url = "?".join((self.geocode_api, urlencode(params)))
         logger.debug("%s.geocode_api: %s", self.__class__.__name__, url)
